==> qt6-webengine_6.2.4+dfsg.orig.tar.xz: qtwebengine-everywhere-src-6.2.4/src/3rdparty/chromium/components/cast/api_bindings/scoped_api_binding.cc <==
// Copyright 2020 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#include "components/cast/api_bindings/scoped_api_binding.h"

#include <string>

#include "base/bind.h"
#include "base/logging.h"
#include "components/cast/api_bindings/manager.h"

namespace cast_api_bindings {

ScopedApiBinding::ScopedApiBinding(Manager* bindings_manager,
                                   Delegate* delegate,
                                   base::StringPiece js_bindings_id,
                                   base::StringPiece js_bindings)
    : bindings_manager_(bindings_manager),
      delegate_(delegate),
      js_bindings_id_(js_bindings_id) {
  DCHECK(bindings_manager_);
  DCHECK(!js_bindings_id_.empty());

  bindings_manager_->AddBinding(js_bindings_id_, js_bindings);

  if (delegate_) {
    bindings_manager_->RegisterPortHandler(
        delegate_->GetPortName(),
        base::BindRepeating(&ScopedApiBinding::OnPortConnected,
                            base::Unretained(this)));
  }
}

ScopedApiBinding::~ScopedApiBinding() {
  // TODO(crbug.com/1104369): Remove binding JS when RemoveBinding() added to
  // ApiBindingsManager.

  if (delegate_) {
    bindings_manager_->UnregisterPortHandler(delegate_->GetPortName());
  }
}

void ScopedApiBinding::OnPortConnected(
    std::unique_ptr<cast_api_bindings::MessagePort> port) {
  message_port_ = std::move(port);
  message_port_->SetReceiver(this);
  delegate_->OnConnected();
}

bool ScopedApiBinding::SendMessage(base::StringPiece data_utf8) {
  DCHECK(delegate_);

  DVLOG(1) << "SendMessage: message=" << data_utf8;
  if (!message_port_->CanPostMessage()) {
    LOG(WARNING)
        << "Attempted to write to unconnected MessagePort, dropping message.";
    return false;
  }

  if (!message_port_->PostMessage(data_utf8.as_string())) {
    return false;
  }

  return true;
}

bool ScopedApiBinding::OnMessage(
    base::StringPiece message,
    std::vector<std::unique_ptr<cast_api_bindings::MessagePort>> ports) {
  return delegate_->OnMessage(message);
}

void ScopedApiBinding::OnPipeError() {
  delegate_->OnDisconnected();
}

}  // namespace cast_api_bindings

==> qt6-webengine_6.4.2+dfsg-0rc0.orig.tar.xz: qtwebengine-everywhere-src-6.4.2/src/3rdparty/chromium/components/cast/api_bindings/scoped_api_binding.cc <==
// Copyright 2020 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#include "components/cast/api_bindings/scoped_api_binding.h"

#include <string>

#include "base/bind.h"
#include "base/logging.h"
#include "base/strings/string_piece.h"
#include "components/cast/api_bindings/manager.h"

namespace cast_api_bindings {

ScopedApiBinding::ScopedApiBinding(Manager* bindings_manager,
                                   Delegate* delegate,
                                   base::StringPiece js_bindings_id,
                                   base::StringPiece js_bindings)
    : bindings_manager_(bindings_manager),
      delegate_(delegate),
      js_bindings_id_(js_bindings_id) {
  DCHECK(bindings_manager_);
  DCHECK(!js_bindings_id_.empty());

  bindings_manager_->AddBinding(js_bindings_id_, js_bindings);

  if (delegate_) {
    bindings_manager_->RegisterPortHandler(
        delegate_->GetPortName(),
        base::BindRepeating(&ScopedApiBinding::OnPortConnected,
                            base::Unretained(this)));
  }
}

ScopedApiBinding::~ScopedApiBinding() {
  // TODO(crbug.com/1104369): Remove binding JS when RemoveBinding() added to
  // ApiBindingsManager.

  if (delegate_) {
    bindings_manager_->UnregisterPortHandler(delegate_->GetPortName());
  }
}

void ScopedApiBinding::OnPortConnected(
    std::unique_ptr<cast_api_bindings::MessagePort> port) {
  message_port_ = std::move(port);
  message_port_->SetReceiver(this);
  delegate_->OnConnected();
}

bool ScopedApiBinding::SendMessage(base::StringPiece data_utf8) {
  DCHECK(delegate_);

  DVLOG(1) << "SendMessage: message=" << data_utf8;
  if (!message_port_->CanPostMessage()) {
    LOG(WARNING)
        << "Attempted to write to unconnected MessagePort, dropping message.";
    return false;
  }

  if (!message_port_->PostMessage(data_utf8)) {
    return false;
  }

  return true;
}

bool ScopedApiBinding::OnMessage(
    base::StringPiece message,
    std::vector<std::unique_ptr<cast_api_bindings::MessagePort>> ports) {
  return delegate_->OnMessage(message);
}

void ScopedApiBinding::OnPipeError() {
  delegate_->OnDisconnected();
}

}  // namespace cast_api_bindings
